KataCxResponse class
A complete (non-streamed) HTTP response.
Constructors
- KataCxResponse({required int statusCode, required String body})
-
Creates a response.
const
Properties
- body → String
-
Decoded response body. Empty string when the server sent none.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccessful → bool
-
Whether the status code is in the 2xx range.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited